@@ -2,13 +2,13 @@ package Class::DBI::Loader::Pg;
 
 use strict;
 use DBI;
-use Carp ();
+use Carp;
 require Class::DBI::Pg;
 require Class::DBI::Loader::Generic;
 use base qw(Class::DBI::Loader::Generic);
 use vars qw($VERSION);
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 =head1 NAME
 
@@ -34,28 +34,16 @@ please see L<Class::DBI::Loader>
 
 =cut
 
-sub _croak { require Carp; Carp::croak(@_); }
+sub _db_class { return 'Class::DBI::Pg' }
 
-sub _load_classes {
+sub _tables {
     my $self = shift;
-    my $dbh = DBI->connect( @{ $self->_datasource } ) or _croak($DBI::errstr);
+    my $dbh = DBI->connect( @{ $self->_datasource } ) or croak($DBI::errstr);
     my @tables;
     if ( $DBD::Pg::VERSION >= 1.31 ) {
-        @tables =
-          $dbh->tables( undef, "public", "", "table", { noprefix => 1 } );
+        return $dbh->tables( undef, "public", "", "table", { noprefix => 1 } );
     }
-    else {
-        @tables = $dbh->tables;
-    }
-    foreach my $table (@tables) {
-        my $class = $self->_table2class($table);
-        no strict 'refs';
-        @{"$class\::ISA"} = qw(Class::DBI::Pg);
-        $class->set_db( Main => @{ $self->_datasource } );
-        $class->set_up_table($table);
-        $self->{CLASSES}->{$table} = $class;
-    }
-    $dbh->disconnect;
+    else { return $dbh->tables }
 }
 
 =head1 SEE ALSO
