@@ -2,13 +2,13 @@ package Class::DBI::Loader::SQLite;
 
 use strict;
 use DBI;
-use Carp ();
+use Carp;
 require Class::DBI::SQLite;
 require Class::DBI::Loader::Generic;
 use base qw(Class::DBI::Loader::Generic);
 use vars qw($VERSION);
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 =head1 NAME
 
@@ -32,11 +32,11 @@ please see L<Class::DBI::Loader>
 
 =cut
 
-sub _croak { require Carp; Carp::croak(@_); }
+sub _db_class { return 'Class::DBI::SQLite' }
 
-sub _load_classes {
+sub _tables {
     my $self = shift;
-    my $dbh  = DBI->connect( @{ $self->_datasource } ) or _croak($DBI::errstr);
+    my $dbh  = DBI->connect( @{ $self->_datasource } ) or croak($DBI::errstr);
     my $sth  = $dbh->prepare("SELECT * FROM sqlite_master");
     $sth->execute;
     my @tables;
@@ -44,17 +44,7 @@ sub _load_classes {
         next unless lc( $row->{type} ) eq 'table';
         push @tables, $row->{tbl_name};
     }
-    $sth->finish;
-    $dbh->disconnect;
-    foreach my $table (@tables) {
-        my $class = $self->_table2class($table);
-        no strict 'refs';
-        @{"$class\::ISA"} = qw(Class::DBI::SQLite);
-        $class->set_db( Main => @{ $self->_datasource } );
-        $class->set_up_table($table);
-        $self->{CLASSES}->{$table} = $class;
-    }
-    $dbh->disconnect;
+    return @tables;
 }
 
 =head1 SEE ALSO
