@@ -2,13 +2,13 @@ package Class::DBI::Loader::mysql;
 
 use strict;
 use DBI;
-use Carp ();
+use Carp;
 require Class::DBI::mysql;
 require Class::DBI::Loader::Generic;
 use base qw(Class::DBI::Loader::Generic);
 use vars qw($VERSION);
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 =head1 NAME
 
@@ -34,22 +34,18 @@ please see L<Class::DBI::Loader>
 
 =cut
 
-sub _croak { require Carp; Carp::croak(@_); }
+sub _db_class { return 'Class::DBI::mysql' }
 
-sub _load_classes {
+sub _tables {
     my $self = shift;
-    my $dbh = DBI->connect( @{ $self->_datasource } ) or _croak($DBI::errstr);
+    my $dbh = DBI->connect( @{ $self->_datasource } ) or croak($DBI::errstr);
+    my @tables;
     foreach my $table ( $dbh->tables ) {
         my $quoter = $dbh->get_info(29);
         $table =~ s/$quoter//g;
-        my $class = $self->_table2class($table);
-        no strict 'refs';
-        @{"$class\::ISA"} = qw(Class::DBI::mysql);
-        $class->set_db( Main => @{ $self->_datasource } );
-        $class->set_up_table($table);
-        $self->{CLASSES}->{$table} = $class;
+        push @tables, $table;
     }
-    $dbh->disconnect;
+    return @tables;
 }
 
 =head1 SEE ALSO
